# A Sparse Merkle Tree for KERI event messages.

Project Name:  sparse-kerkle-tree

[![PyPi](https://img.shields.io/pypi/v/kerkle.svg)](https://pypi.org/project/kerkle/)
[![GitHub Actions](https://github.com/webOfTrust/sparse-kerkle-tree/actions/workflows/python-app-ci.yml/badge.svg)](https://github.com/WebOfTrust/sparse-kerkle-tree/actions)
[![codecov](https://codecov.io/gh/WebOfTrust/sparse-kerkle-tree/branch/main/graph/badge.svg?token=FR5CB2TPYG)](https://codecov.io/gh/WebOfTrust/sparse-kerkle-tree)
[![https://pypi.org/project/kerkle/](https://img.shields.io/pypi/pyversions/kerkle.svg)](https://pypi.org/project/kerkle/)

## Installation

### Local installation - build from source

`$ pip install -r requirements.txt`


